@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.2.17
+# Version   : 0.2.18
 
 import  numpy                   as      np
 import  plotly.graph_objects    as      go
@@ -580,7 +580,7 @@ class AFM:
                 _z_w = np.append(_z_w, blank)
 
             if len(adjusted_approach) < 10 or len(adjusted_retract) < 10 :
-                break
+                continue
 
             if approach_dev < max_approach_noise and retract_dev < max_retract_noise:
 
